Author: Andreas Tille <tille@debian.org>
Last-Update: Fri, 22 Sep 2017 09:18:47 +0200
Description: Fix spelling issues

--- a/src/dynlibsrc/hscore.c
+++ b/src/dynlibsrc/hscore.c
@@ -413,7 +413,7 @@ DataScore * new_DataScore_from_storage(H
   if( hs->st_len == 0 ) {
     new = new_DataScoreStorage();
     if( new == NULL ) {
-      warn("could not make inital data score storage!");
+      warn("could not make initial data score storage!");
       return NULL;
     }
     add_st_Hscore(hs,new);
--- a/src/dynlibsrc/hscore.dy
+++ b/src/dynlibsrc/hscore.dy
@@ -422,7 +422,7 @@ DataScore * new_DataScore_from_storage(H
   if( hs->st_len == 0 ) {
     new = new_DataScoreStorage();
     if( new == NULL ) {
-      warn("could not make inital data score storage!");
+      warn("could not make initial data score storage!");
       return NULL;
     }
     add_st_Hscore(hs,new);
--- a/docs/dynamite.tex
+++ b/docs/dynamite.tex
@@ -2839,7 +2839,7 @@ needs at least one offset to be non zero
 Once all the semantics of the Dynamite blueprint is ok, the compiler then turns its
 attention to the calc lines. This is like a mini-parser operating inside the dynamite
 parser, but unlike the dynamite parser, this once was written in yacc/lex and is
-a more vanilla parser enviroment.
+a more vanilla parser environment.
 
 \subsubsection{Parser Syntax error on calc line}
 
--- a/docs/wise2.tex
+++ b/docs/wise2.tex
@@ -121,7 +121,7 @@ Warning Error
         Could not read a GeneFrequency file in human.gf
 ...
 \end{verbatim}
-This means that the enviroment variable WISECONFIGDIR has not been
+This means that the environment variable WISECONFIGDIR has not been
 set up correctly. You need to find where the distribution was downloaded
 to (a directory called something like wise2.1.16b) and inside that
 directory should be the configuration directory wisecfg. You need to
@@ -427,7 +427,7 @@ sequence flag) as well. An example run w
 \begin{verbatim}
 genewisedb -pfam Pfam -dnas myseq.fa
 \end{verbatim}
-If you have set up the HMMER package to work with Pfam using the enviroment
+If you have set up the HMMER package to work with Pfam using the environment
 variable HMMERDB, Wise2 will also pick that up as well.
 
 
@@ -675,7 +675,7 @@ mathematically it is almost that easy: t
 of the probability.
 
 Perhaps a better known example is the relationship between the old
-profile technology, as developped by Gribskov and Gibson along with
+profile technology, as developed by Gribskov and Gibson along with
 others, and its probabilistic partner, profile Hidden Markov Models
 (profile HMMs).  In terms of the actual algorithm these two methods
 are very similar: it is simply that the profile HMM has a strong
@@ -1639,7 +1639,7 @@ Of course there are many options to chan
 \subsection{dba - Dna Block Aligner}
 \label{sec:dba}
 
-dba - standing for Dna Block Aligner, was developped by Niclas Jareborg,
+dba - standing for Dna Block Aligner, was developed by Niclas Jareborg,
 Richard Durbin and Ewan Birney for characterising shared regulatory regions
 of genomic DNA, either in upstream regions or introns of genes
 
--- a/src/base/wisefile.c
+++ b/src/base/wisefile.c
@@ -329,7 +329,7 @@ FILE * openfile(const char * filename,co
  *
  *
  *
- * Arg:         envname [READ ] enviroment variable to read from [NullString]
+ * Arg:         envname [READ ] environment variable to read from [NullString]
  * Arg:        filename [UNKN ] Undocumented argument [char *]
  * Arg:            name [READ ] filename to open [NullString]
  * Arg:             env [UNKN ] Undocumented argument [char *]
@@ -344,17 +344,17 @@ FILE * envopenfile(char * filename,char
   char path [512];
 
   if( filename == NULL || env == NULL ) {
-    warn("Passed a NULL filename or enviroment name into Envfile. Should trap this elsewhere");
+    warn("Passed a NULL filename or environment name into Envfile. Should trap this elsewhere");
     return NULL;
   }
 
   if( (envp = getenv(env)) == NULL ) {
-    /* fail gracefully - somebody might query a number of enviroment variables */
+    /* fail gracefully - somebody might query a number of environment variables */
     return NULL;
   }
 
   if( strlen(filename) + strlen(envp) < 490 ) {
-    warn("Really long filename/enviroment variables [%s] [%s] Can't cope!",filename,envp);
+    warn("Really long filename/environment variables [%s] [%s] Can't cope!",filename,envp);
     return NULL;
   }
   sprintf(path,"%s/%s",filename,envp);
--- a/src/base/wisefile.dy
+++ b/src/base/wisefile.dy
@@ -302,7 +302,7 @@ in HMMer2. You call it as
 
 %arg
 name r filename to open
-envname r enviroment variable to read from
+envname r environment variable to read from
 return a valid file pointer or NULL
 %%
 FILE * envopenfile(char * filename,char * env)
@@ -311,17 +311,17 @@ FILE * envopenfile(char * filename,char
   char path [512];
 
   if( filename == NULL || env == NULL ) {
-    warn("Passed a NULL filename or enviroment name into Envfile. Should trap this elsewhere");
+    warn("Passed a NULL filename or environment name into Envfile. Should trap this elsewhere");
     return NULL;
   }
 
   if( (envp = getenv(env)) == NULL ) {
-    /* fail gracefully - somebody might query a number of enviroment variables */
+    /* fail gracefully - somebody might query a number of environment variables */
     return NULL;
   }
 
   if( strlen(filename) + strlen(envp) < 490 ) {
-    warn("Really long filename/enviroment variables [%s] [%s] Can't cope!",filename,envp);
+    warn("Really long filename/environment variables [%s] [%s] Can't cope!",filename,envp);
     return NULL;
   }
   sprintf(path,"%s/%s",filename,envp);
--- a/src/base/wisefile.h
+++ b/src/base/wisefile.h
@@ -143,7 +143,7 @@ FILE * Wise2_openfile(const char * filen
  *
  *
  *
- * Arg:         envname [READ ] enviroment variable to read from [NullString]
+ * Arg:         envname [READ ] environment variable to read from [NullString]
  * Arg:        filename [UNKN ] Undocumented argument [char *]
  * Arg:            name [READ ] filename to open [NullString]
  * Arg:             env [UNKN ] Undocumented argument [char *]
--- a/LICENSE
+++ b/LICENSE
@@ -19,7 +19,7 @@ an acknowledgement of the authorship nee
 
 The HMMer2 libaries (Sean Eddy's HMM package) and the models directory
 (The algorithms for the Wise2 package, and final executable programs)
-are both distributed under a Gnu General Public License (GPL). This
+are both distributed under a GNU General Public License (GPL). This
 means that the entire package as it is distributed with these portions
 in is also licensed under GPL, due to the 'infectious' nature of the
 GPL.
--- a/docs/wise3arch.tex
+++ b/docs/wise3arch.tex
@@ -49,7 +49,7 @@ clear up a considerable amount of confus
 
 \subsection{Committment to open source, freely available code}
 
-The Wise2 package has been licensed under the Gnu Public License since
+The Wise2 package has been licensed under the GNU General Public License since
 its inception.  In addition, parts of the package has even less
 restrictive Licenses. I have a strong committment to keep Wise a
 freely available, open source package. The aim of the open
--- a/src/corba/scanwise_protein_index.c
+++ b/src/corba/scanwise_protein_index.c
@@ -19,7 +19,7 @@ char * program_name = "scanwise_protein_
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/dnaindex/assembly/badkmer.c
+++ b/src/dnaindex/assembly/badkmer.c
@@ -25,7 +25,7 @@ void show_help(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EBI 2003\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/dnaindex/assembly/pathwise.c
+++ b/src/dnaindex/assembly/pathwise.c
@@ -40,7 +40,7 @@ void show_help(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EBI 2003\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/dnaindex/bigseqwise.c
+++ b/src/dnaindex/bigseqwise.c
@@ -10,7 +10,7 @@ char * program_name = "bigseqwise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/dnaindex/findbad_kmer.c
+++ b/src/dnaindex/findbad_kmer.c
@@ -13,7 +13,7 @@ char * program_name = "findbad_kmer";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/dnaindex/kwise.c
+++ b/src/dnaindex/kwise.c
@@ -15,7 +15,7 @@ char * program_name = "kwise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/alignwise.c
+++ b/src/models/alignwise.c
@@ -61,7 +61,7 @@ void show_Gene_debug(AlnBlock * alb,Sequ
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/amplimer_resolver.c
+++ b/src/models/amplimer_resolver.c
@@ -10,7 +10,7 @@ char * program_name = "amplimer_resolver
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/cdnawise.c
+++ b/src/models/cdnawise.c
@@ -15,7 +15,7 @@ void show_version(FILE * ofp)
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
 
 
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL (2001) and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/clonewise.c
+++ b/src/models/clonewise.c
@@ -25,7 +25,7 @@ int mismatch_score   = -1;
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/dbac.c
+++ b/src/models/dbac.c
@@ -363,7 +363,7 @@ void show_version(FILE * ofp)
   fprintf(ofp,"  Released %s\n",RELEASE_DAY);  
   fprintf(ofp,"  Compiled %s\n",COMPILE_DATE);  
   fprintf(ofp,"dba was written by Niclas Jareborg, Ewan Birney and Richard Durbin\n");  
-  fprintf(ofp,"Copyright (c) 1998,1999,2000,2001 GRL ltd. It is distributed under a Gnu Public License\n");  
+  fprintf(ofp,"Copyright (c) 1998,1999,2000,2001 GRL ltd. It is distributed under a GNU General Public License\n");  
   fprintf(ofp,"See GNULICENSE in source directory for more information\n");  
 }  
 
--- a/src/models/dnal.c
+++ b/src/models/dnal.c
@@ -104,7 +104,7 @@ void show_short_help(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/dnawise.c
+++ b/src/models/dnawise.c
@@ -8,7 +8,7 @@ char * program_name = "dnawise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/editdist.c
+++ b/src/models/editdist.c
@@ -8,7 +8,7 @@ char * program_name = "editdist";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/estwise.c
+++ b/src/models/estwise.c
@@ -557,7 +557,7 @@ void show_help(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/estwisedb.c
+++ b/src/models/estwisedb.c
@@ -807,7 +807,7 @@ boolean show_header(FILE * ofp)
   fprintf(ofp,"-------------------------------------------------------------\n");
   fprintf(ofp,"Wise2 - database searching mode\n");
   fprintf(ofp,"Program: %s version: %s released: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY);
-  fprintf(ofp,"This program is freely distributed under a Gnu Public License.\n");
+  fprintf(ofp,"This program is freely distributed under a GNU General Public License.\n");
   fprintf(ofp,"   See -version for more info on copyright\n");
   fprintf(ofp,"Bugs and credits to Ewan Birney <birney@sanger.ac.uk>\n");
   fprintf(ofp,"-------------------------------------------------------------\n\n");
@@ -836,7 +836,7 @@ boolean show_header(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/evopairwise.c
+++ b/src/models/evopairwise.c
@@ -15,7 +15,7 @@ char * program_name = "evopairwise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/fivestar.c
+++ b/src/models/fivestar.c
@@ -14,7 +14,7 @@ char * program_name = "fivestar";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/fivestarscan.c
+++ b/src/models/fivestarscan.c
@@ -14,7 +14,7 @@ char * program_name = "fivestarscan";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/fivestarsearch.c
+++ b/src/models/fivestarsearch.c
@@ -12,7 +12,7 @@ char * program_name = "fivestarsearch";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/genewise.c
+++ b/src/models/genewise.c
@@ -858,7 +858,7 @@ void show_help(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/genewisedb.c
+++ b/src/models/genewisedb.c
@@ -505,7 +505,7 @@ boolean show_header(FILE * ofp)
 {
   fprintf(ofp,"Wise2 - database searching mode\n");
   fprintf(ofp,"Program: %s version: %s released: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY);
-  fprintf(ofp,"This program is freely distributed under a Gnu Public License.\n");
+  fprintf(ofp,"This program is freely distributed under a GNU General Public License.\n");
   fprintf(ofp,"   See -version for more info on copyright\n");
   fprintf(ofp,"Bugs and credits to Ewan Birney <birney@sanger.ac.uk>\n");
   fprintf(ofp,"-----------------------------------------------------\n\n");
@@ -1003,7 +1003,7 @@ void show_help(FILE * ofp)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/genomewise.c
+++ b/src/models/genomewise.c
@@ -16,7 +16,7 @@ void show_utr_exon_genomewise(AlnBlock *
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/lba.c
+++ b/src/models/lba.c
@@ -8,7 +8,7 @@ char * program_name = "lba";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/motifcluster.c
+++ b/src/models/motifcluster.c
@@ -8,7 +8,7 @@ char * program_name = "motifcluster";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/motifdiff.c
+++ b/src/models/motifdiff.c
@@ -8,7 +8,7 @@ char * program_name = "motifdiff";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/motifwise.c
+++ b/src/models/motifwise.c
@@ -8,7 +8,7 @@ char * program_name = "motifwise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/oldpostwise.c
+++ b/src/models/oldpostwise.c
@@ -375,7 +375,7 @@ void show_help(char * help_arg)
 void show_version(void)
 {
   fprintf(stdout,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(stdout,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(stdout,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(stdout,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(stdout,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(stdout,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/promotercluster.c
+++ b/src/models/promotercluster.c
@@ -7,7 +7,7 @@ char * program_name = "promotercluster";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/promoterwise.c
+++ b/src/models/promoterwise.c
@@ -15,7 +15,7 @@ char * program_name = "promoterwise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/pseudowise.c
+++ b/src/models/pseudowise.c
@@ -13,7 +13,7 @@ char * program_name = "pseudowise";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/psw.c
+++ b/src/models/psw.c
@@ -259,7 +259,7 @@ int main(int argc,char ** argv)
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) GRL 1998 and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/pswdb.c
+++ b/src/models/pswdb.c
@@ -95,7 +95,7 @@ void show_help(FILE * ofp)
 void show_version(void)
 {
   fprintf(stdout,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(stdout,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(stdout,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(stdout,"The source code is copyright (c) EMBL 1998 and others\n");
   fprintf(stdout,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(stdout,"For more information read the GNULICENSE file in the distribution\n\n");
@@ -347,7 +347,7 @@ boolean show_header(FILE * ofp)
   fprintf(ofp,"-------------------------------------------------------------\n");
   fprintf(ofp,"Wise2 - Protein vs. Protein\n");
   fprintf(ofp,"Program: %s version: %s released: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY);
-  fprintf(ofp,"This program is freely distributed under a Gnu Public License.\n");
+  fprintf(ofp,"This program is freely distributed under a GNU General Public License.\n");
   fprintf(ofp,"   See -version for more info on copyright\n");
   fprintf(ofp,"Bugs and credits to: Richard Copley <copley@embl-heidelberg.de>\n"); 
   fprintf(ofp,"                     Ewan Birney <birney@sanger.ac.uk>\n");
--- a/src/models/scanwisep.c
+++ b/src/models/scanwisep.c
@@ -421,7 +421,7 @@ HitList * HitList_from_HSP_HSP2HitListIm
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/statwise.c
+++ b/src/models/statwise.c
@@ -11,7 +11,7 @@ char * codon_table = "codon.table";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/models/sywise.c
+++ b/src/models/sywise.c
@@ -12,7 +12,7 @@ char * codon_table = "codon.table";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/network/wise_proteinindex_server.c
+++ b/src/network/wise_proteinindex_server.c
@@ -26,7 +26,7 @@ char * program_name = "scanwise_server";
 void show_version(FILE * ofp)
 {
   fprintf(ofp,"%s\nVersion: %s\nReleased: %s\nCompiled: %s\n",program_name,VERSION_NUMBER,RELEASE_DAY,COMPILE_DATE);
-  fprintf(ofp,"\nThis program is freely distributed under a Gnu Public License\n");
+  fprintf(ofp,"\nThis program is freely distributed under a GNU General Public License\n");
   fprintf(ofp,"The source code is copyright (c) EMBL and others\n");
   fprintf(ofp,"There is no warranty, implied or otherwise on the performance of this program\n");
   fprintf(ofp,"For more information read the GNULICENSE file in the distribution\n\n");
--- a/src/test/estwise-db.out
+++ b/src/test/estwise-db.out
@@ -1,7 +1,7 @@
 -------------------------------------------------------------
 Wise2 - database searching mode
 Program: estwisedb version: $Name: wise2-4-1 $ released: unreleased
-This program is freely distributed under a Gnu Public License.
+This program is freely distributed under a GNU General Public License.
    See -version for more info on copyright
 Bugs and credits to Ewan Birney <birney@sanger.ac.uk>
 -------------------------------------------------------------
--- a/src/test/genewise-db-lite.out
+++ b/src/test/genewise-db-lite.out
@@ -1,6 +1,6 @@
 Wise2 - database searching mode
 Program: genewisedb version: $Name: wise2-4-1 $ released: unreleased
-This program is freely distributed under a Gnu Public License.
+This program is freely distributed under a GNU General Public License.
    See -version for more info on copyright
 Bugs and credits to Ewan Birney <birney@sanger.ac.uk>
 -----------------------------------------------------
--- a/src/test/genewise-db.out
+++ b/src/test/genewise-db.out
@@ -1,6 +1,6 @@
 Wise2 - database searching mode
 Program: genewisedb version: $Name: wise2-4-1 $ released: unreleased
-This program is freely distributed under a Gnu Public License.
+This program is freely distributed under a GNU General Public License.
    See -version for more info on copyright
 Bugs and credits to Ewan Birney <birney@sanger.ac.uk>
 -----------------------------------------------------
--- a/src/test/genewisedb-pfam.out
+++ b/src/test/genewisedb-pfam.out
@@ -1,6 +1,6 @@
 Wise2 - database searching mode
 Program: genewisedb version: $Name: wise2-4-1 $ released: unreleased
-This program is freely distributed under a Gnu Public License.
+This program is freely distributed under a GNU General Public License.
    See -version for more info on copyright
 Bugs and credits to Ewan Birney <birney@sanger.ac.uk>
 -----------------------------------------------------
--- a/src/test/pswdb.out
+++ b/src/test/pswdb.out
@@ -1,7 +1,7 @@
 -------------------------------------------------------------
 Wise2 - Protein vs. Protein
 Program: pswdb version: $Name: wise2-4-1 $ released: unreleased
-This program is freely distributed under a Gnu Public License.
+This program is freely distributed under a GNU General Public License.
    See -version for more info on copyright
 Bugs and credits to: Richard Copley <copley@embl-heidelberg.de>
                      Ewan Birney <birney@sanger.ac.uk>
--- a/src/models/genefrequency.c
+++ b/src/models/genefrequency.c
@@ -636,7 +636,7 @@ double double_from_line(char * buffer)
   ret = strtod(runner,&end);
 
   if( end == runner || isalnum((int)*end) ) {
-    warn("Bad conversion of string [%s] to double [%f] occured",runner,ret);
+    warn("Bad conversion of string [%s] to double [%f] occurred",runner,ret);
   }
 
   return ret;
--- a/src/models/genefrequency.dy
+++ b/src/models/genefrequency.dy
@@ -597,7 +597,7 @@ double double_from_line(char * buffer)
   ret = strtod(runner,&end);
 
   if( end == runner || isalnum((int)*end) ) {
-    warn("Bad conversion of string [%s] to double [%f] occured",runner,ret);
+    warn("Bad conversion of string [%s] to double [%f] occurred",runner,ret);
   }
 
   return ret;
--- a/src/models/seqerror.dy
+++ b/src/models/seqerror.dy
@@ -42,7 +42,7 @@ Sequence * seq
 SequenceErrorSet * ses
 %info
 This holds a sequence and what
-errors have occured in it.
+errors have occurred in it.
 %%
 
 
--- a/src/models/seqerror.h
+++ b/src/models/seqerror.h
@@ -72,7 +72,7 @@ typedef struct Wise2_SequenceErrorSet Wi
 /* Object ErrorSequence
  *
  * Descrip: This holds a sequence and what
- *        errors have occured in it.
+ *        errors have occurred in it.
  *
  *
  */
